﻿using Database;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace View
{
	public partial class InvitedForm : Form
	{
		private Abstracts db;
		private int? index;
		public InvitedForm(Abstracts abstracts)
		{
			InitializeComponent();
			db = abstracts;
		}

		private void buttonReload_Click(object sender, EventArgs e)
		{
			LoadData();
		}

		private void buttonDelete_Click(object sender, EventArgs e)
		{
			if (dataGridView1.SelectedRows.Count == 1)
			{
				int id = Convert.ToInt32(dataGridView1.SelectedRows[0].Cells["UserId"].Value);
				try
				{
					db.DeleteInvite(id, index.Value);
					LoadData();
				}
				catch (Exception ex)
				{
					MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
				}
			}
		}

		private void buttonCreate_Click(object sender, EventArgs e)
		{
			var service = Program.ServiceProvider?.GetService(typeof(InviteForm));
			if (service is InviteForm form)
			{
				form.DateId = index.Value;
				if (form.ShowDialog() == DialogResult.OK)
				{
					LoadData();
				}
			}
		}

		private void InvitedForm_Load(object sender, EventArgs e)
		{
			LoadDatas();
		}
		private void LoadData()
		{
			if (dataGridView1.Columns.Count == 0)
			{
				dataGridView1.Columns.Add("UserId", "UserId");
				dataGridView1.Columns.Add("DateId", "DateId");
			}
			try
			{
				if (!index.HasValue)
					return;
				var list = db.GetInvited(index.Value);
				dataGridView1.Rows.Clear();
				foreach (var i in list)
				{
					dataGridView1.Rows.Add(i.userId, i.typeId);
				}
			}
			catch (Exception ex)
			{
				MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
			}
		}
		private void LoadDatas()
		{
			try
			{
				var list = db.GetDatas();
				comboBox1.DataSource = list;
				comboBox1.DisplayMember = "DateTime";
				comboBox1.ValueMember = "Id";
			}
			catch (Exception ex)
			{
				MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
			}
		}

		private void comboBox1_SelectedIndexChanged(object sender, EventArgs e)
		{
			try
			{
				var item = comboBox1.SelectedItem as Data;
				index = item!.Id;
				LoadData();
			}
			catch (Exception ex)
			{
				MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
			}
		}
	}
}
